@@ -212,7 +212,8 @@ class AppServer(Config):
     def local_only(self, call):
         def _wrapped(*args, **kwargs):
             remote_addr = utils.get_remote_addr()
-            if remote_addr not in ('127.0.0.1', '::1', self.localhost_ip):
+            if remote_addr not in ('127.0.0.1', '::1', self.localhost_ip,
+                    self.bind_addr):
                 logger.error('Local only handler auth error. %r' % {
                     'remote_addr': remote_addr,
                 })
