@@ -15,7 +15,11 @@ RESTART = 'restart'
 OK = 'ok'
 DISABLED = 'disabled'
 
-NAME_SAFE_CHARS = {'-', '=', '_', '@', '.', ':', '/'}
+NAME_SAFE_CHARS = {
+    '-', '=', '_', '@', '.', ':', '/',
+    '!', '#', '$', '%', '&', '*', '+',
+    '?', '^', '`', '{', '|', '}', '~',
+}
 
 KEY_LINK_TIMEOUT = 86400
 DEFAULT_BIND_ADDR = '0.0.0.0'
@@ -35,6 +39,7 @@ DEFAULT_OTP_SECRET_LEN = 16
 DEFAULT_PUBLIC_IP_SERVER = 'http://ip.pritunl.com/json'
 DEFAULT_NOTIFICATION_SERVER = 'http://ip.pritunl.com/notification'
 SUBSCRIPTION_SERVER = 'https://app.pritunl.com/subscription'
+POSTMARK_SERVER = 'https://api.postmarkapp.com/email'
 UPDATE_CHECK_RATE = 3600
 ENV_PREFIX = APP_NAME
 LOG_LIMIT = 100
@@ -57,6 +62,7 @@ STATIC_CACHE_TIME = 43200
 LOCALHOST_IP_TTL = 30
 AUTH_SIG_STRING_MAX_LEN = 10240
 AUTH_TIME_WINDOW = 300
+OTP_CACHE_TTL = 43200
 IP_REGEX = r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}'
 SAFE_PUB_SUBNETS = {'50.203.224.0/24'}
 STATIC_FILE_EXTENSIONS = {
@@ -134,7 +140,7 @@ VALID_IP_ENDPOINTS = {
     '101', '105', '109', '113', '117', '121', '125', '129', '133', '137',
     '141', '145', '149', '153', '157', '161', '165', '169', '173', '177',
     '181', '185', '189', '193', '197', '201', '205', '209', '213', '217',
-    '221', '225', '229', '233', '237', '241', '245', '249', '253'
+    '221', '225', '229', '233', '237', '241', '245', '249', '253',
 }
 
 OPENSSL_HEARTBLEED = {
@@ -314,6 +320,17 @@ USER_TYPE_INVALID_MSG = 'User type is not valid.'
 OTP_CODE_INVALID = 'otp_code_invalid'
 OTP_CODE_INVALID_MSG = 'OTP code is not valid.'
 
+EMAIL_NOT_CONFIGURED = 'email_not_configured'
+EMAIL_NOT_CONFIGURED_MSG = 'Required email settings have not been ' + \
+    'configured, please open settings and configure email.'
+
+EMAIL_FROM_INVALID = 'email_from_invalid'
+EMAIL_FROM_INVALID_MSG = 'Postmark sender signature not defined ' + \
+    'for from address.'
+
+EMAIL_API_KEY_INVALID = 'email_api_key_invalid'
+EMAIL_API_KEY_INVALID_MSG = 'Postmark email api key invalid.'
+
 SUBSCRIPTION_SERVER_ERROR = 'subscription_server_error'
 SUBSCRIPTION_SERVER_ERROR_MSG = 'Unable to connect to ' + \
     'subscription server, please try again later.'
@@ -329,9 +346,8 @@ client-connect %s
 client-disconnect %s
 dh %s
 server %s
-%s
 max-clients 1024
-keepalive 10 %s
+keepalive 10 60
 persist-tun
 status %s 1
 status-version 2
@@ -347,9 +363,8 @@ tls-verify %s
 client-connect %s
 client-disconnect %s
 server %s
-%s
 max-clients 1024
-keepalive 10 %s
+keepalive 10 60
 persist-tun
 status %s 1
 status-version 2
@@ -435,7 +450,7 @@ try:
         exit(1)
 
     try:
-        request = Request('%s://localhost:%s' + \\
+        request = Request('%s://%s:%s' + \\
             '/server/%s/tls_verify')
         request.add_header('Content-Type', 'application/json')
         response = urlopen(request, json.dumps({
@@ -498,6 +513,7 @@ try:
 
     # Get org and common_name from environ
     tls_env = os.environ.get('tls_id_0')
+    remote_ip = os.environ.get('untrusted_ip')
     if not tls_env:
         log_write('[FAILED] Missing organization or user id from environ')
         raise AttributeError('Missing organization or user id from environ')
@@ -527,13 +543,14 @@ try:
         raise TypeError('Authenticator code is invalid')
 
     try:
-        request = Request('%s://localhost:%s' + \\
+        request = Request('%s://%s:%s' + \\
             '/server/%s/otp_verify')
         request.add_header('Content-Type', 'application/json')
         response = urlopen(request, json.dumps({
             'org_id': org,
             'user_id': common_name,
             'otp_code': password,
+            'remote_ip': remote_ip,
         }).encode('utf-8'))
         response = json.loads(response.read().decode('utf-8'))
 
@@ -611,7 +628,7 @@ try:
         raise AttributeError('Missing organization or user id from environ')
 
     try:
-        request = Request('%s://localhost:%s' + \\
+        request = Request('%s://%s:%s' + \\
             '/server/%s/client_connect')
         request.add_header('Content-Type', 'application/json')
         response = urlopen(request, json.dumps({
@@ -694,7 +711,7 @@ try:
         raise AttributeError('Missing organization or user id from environ')
 
     try:
-        request = Request('%s://localhost:%s' + \\
+        request = Request('%s://%s:%s' + \\
             '/server/%s/client_disconnect')
         request.add_header('Content-Type', 'application/json')
         response = urlopen(request, json.dumps({
