@@ -244,6 +244,12 @@ def server_put_post(server_id=None):
             if not re.match(IP_REGEX, dns_server):
                 return _dns_server_invalid()
 
+    search_domain = None
+    search_domain_def = False
+    if 'search_domain' in flask.request.json:
+        search_domain_def = True
+        search_domain = utils.filter_str(flask.request.json['search_domain'])
+
     public_address = None
     public_address_def = False
     if 'public_address' in flask.request.json:
@@ -390,6 +396,7 @@ def server_put_post(server_id=None):
                 mode=mode,
                 local_networks=local_networks,
                 dns_servers=dns_servers,
+                search_domain=search_domain,
                 public_address=public_address,
                 otp_auth=otp_auth,
                 lzo_compression=lzo_compression,
@@ -409,6 +416,7 @@ def server_put_post(server_id=None):
                 mode=mode,
                 local_networks=local_networks,
                 dns_servers=dns_servers,
+                search_domain=search_domain,
                 public_address=public_address,
                 otp_auth=otp_auth,
                 lzo_compression=lzo_compression,
@@ -439,6 +447,8 @@ def server_put_post(server_id=None):
             server.local_networks = local_networks
         if dns_servers_def:
             server.dns_servers = dns_servers
+        if search_domain_def:
+            server.search_domain = search_domain
         if public_address_def:
             server.public_address = public_address
         if otp_auth_def:
@@ -587,6 +597,13 @@ def server_tls_verify_post(server_id):
             'error': USER_INVALID,
             'error_msg': USER_INVALID_MSG,
         }, 401)
+    if user.disabled:
+        LogEntry(message='User failed authentication, ' +
+            'disabled user "%s".' % server.name)
+        return utils.jsonify({
+            'error': USER_INVALID,
+            'error_msg': USER_INVALID_MSG,
+        }, 401)
 
     return utils.jsonify({
         'authenticated': True,
@@ -598,6 +615,7 @@ def server_otp_verify_post(server_id):
     org_id = flask.request.json['org_id']
     user_id = flask.request.json['user_id']
     otp_code = flask.request.json['otp_code']
+    remote_ip = flask.request.json.get('remote_ip')
 
     server = Server(server_id)
     if not server:
@@ -621,7 +639,7 @@ def server_otp_verify_post(server_id):
             'error': USER_INVALID,
             'error_msg': USER_INVALID_MSG,
         }, 401)
-    if not user.verify_otp_code(otp_code):
+    if not user.verify_otp_code(otp_code, remote_ip):
         LogEntry(message='User failed two-step authentication "%s".' % (
             user.name))
         return utils.jsonify({
