@@ -25,7 +25,8 @@ logger = logging.getLogger(APP_NAME)
 class Server(Config):
     str_options = {'name', 'network', 'interface', 'protocol', 'mode',
         'local_networks', 'public_address', 'primary_organization',
-        'primary_user', 'organizations', 'local_network', 'dns_servers'}
+        'primary_user', 'organizations', 'local_network', 'dns_servers',
+        'search_domain'}
     bool_options = {'otp_auth', 'lzo_compression', 'debug'}
     int_options = {'port', 'dh_param_bits'}
     list_options = {'organizations', 'local_networks', 'dns_servers'}
@@ -122,6 +123,7 @@ class Server(Config):
             'mode': self.mode,
             'local_networks': self.local_networks,
             'dns_servers': self.dns_servers,
+            'search_domain': self.search_domain,
             'public_address': self.public_address,
             'otp_auth': True if self.otp_auth else False,
             'lzo_compression': self.lzo_compression,
@@ -495,6 +497,9 @@ class Server(Config):
         logger.debug('Generating openvpn scripts. %r' % {
             'server_id': self.id,
         })
+        auth_host = app_server.bind_addr
+        if auth_host == '0.0.0.0':
+            auth_host = 'localhost'
         for script, script_path in (
                     (TLS_VERIFY_SCRIPT, self.tls_verify_path),
                     (USER_PASS_VERIFY_SCRIPT, self.user_pass_verify_path),
@@ -506,6 +511,7 @@ class Server(Config):
                 script_file.write(script % (
                     self.auth_log_path,
                     app_server.web_protocol,
+                    auth_host,
                     app_server.port,
                     self.id,
                 ))
@@ -550,7 +556,8 @@ class Server(Config):
             push += 'push "redirect-gateway"\n'
         for dns_server in self.dns_servers:
             push += 'push "dhcp-option DNS %s"\n' % dns_server
-        push = push.rstrip()
+        if self.search_domain:
+            push += 'push "dhcp-option DOMAIN %s"\n' % self.search_domain
 
         if not inline:
             server_conf = OVPN_SERVER_CONF % (
@@ -565,8 +572,6 @@ class Server(Config):
                 self.client_disconnect_path,
                 self.dh_param_path,
                 '%s %s' % self._parse_network(self.network),
-                push,
-                '120' if self.otp_auth else '60',
                 self.ovpn_status_path,
                 4 if self.debug else 1,
                 8 if self.debug else 3,
@@ -580,8 +585,6 @@ class Server(Config):
                 self.client_connect_path,
                 self.client_disconnect_path,
                 '%s %s' % self._parse_network(self.network),
-                push,
-                '120' if self.otp_auth else '60',
                 self.ovpn_status_path,
                 4 if self.debug else 1,
                 8 if self.debug else 3,
@@ -597,6 +600,9 @@ class Server(Config):
         if self.mode in (LOCAL_TRAFFIC, VPN_TRAFFIC):
             server_conf += 'client-to-client\n'
 
+        if push:
+            server_conf += push
+
         if inline:
             server_conf += '<ca>\n%s\n</ca>\n' % utils.get_cert_block(
                 self.ca_cert_path)
