@@ -1,6 +1,7 @@
 from constants import *
+from exceptions import *
 from pritunl import app_server
-from cache import cache_db
+from cache import cache_db, persist_db
 from cache_trie import CacheTrie
 from config import Config
 from log_entry import LogEntry
@@ -22,15 +23,17 @@ import json
 logger = logging.getLogger(APP_NAME)
 
 class User(Config):
-    str_options = {'name', 'otp_secret', 'type'}
+    str_options = {'name', 'email', 'otp_secret', 'type'}
+    bool_options = {'disabled'}
     default_options = {
         'name': 'undefined',
+        'disabled': False,
     }
     chmod_mode = 0600
     cached = True
     cache_prefix = 'user'
 
-    def __init__(self, org, id=None, name=None, type=None):
+    def __init__(self, org, id=None, name=None, email=None, type=None):
         Config.__init__(self)
         self.org = org
 
@@ -42,6 +45,7 @@ class User(Config):
             else:
                 self.id = uuid.uuid4().hex
             self.name = name
+            self.email = email
             self.type = type
         else:
             self.id = id
@@ -72,8 +76,10 @@ class User(Config):
             'organization': self.org.id,
             'organization_name': self.org.name,
             'name': self.name,
+            'email': self.email,
             'type': self.type,
             'otp_secret': self.otp_secret,
+            'disabled': self.disabled,
         }
 
     def _upgrade_0_10_9(self):
@@ -189,6 +195,14 @@ class User(Config):
             })
             raise
 
+    def get_cache_key(self, suffix=None):
+        if not self.cache_prefix:
+            raise AttributeError('Cached config object requires cache_prefix')
+        key = self.cache_prefix + '-' + self.org.id + '_' + self.id
+        if suffix:
+            key += '-%s' % suffix
+        return key
+
     def load(self, *args, **kwargs):
         Config.load(self, *args, **kwargs)
         if not self.otp_secret:
@@ -211,7 +225,18 @@ class User(Config):
         self._generate_otp_secret()
         Event(type=USERS_UPDATED, resource_id=self.org.id)
 
-    def verify_otp_code(self, code):
+    def verify_otp_code(self, code, remote_ip=None):
+        if remote_ip:
+            otp_cache = cache_db.get(self.get_cache_key('otp_cache'))
+            if otp_cache:
+                cur_code, cur_remote_ip = otp_cache.split(',')
+                if cur_code == code and cur_remote_ip == remote_ip:
+                    cache_db.expire(self.get_cache_key('otp_cache'),
+                        OTP_CACHE_TTL)
+                    return True
+                else:
+                    cache_db.remove(self.get_cache_key('otp_cache'))
+
         otp_secret = self.otp_secret
         padding = 8 - len(otp_secret) % 8
         if padding != 8:
@@ -237,9 +262,12 @@ class User(Config):
                 cache_db.dict_remove(self.get_cache_key('otp'), auth_time)
             if used_code == code:
                 return False
+
         cache_db.dict_set(self.get_cache_key('otp'),
             str(int(time.time())), code)
-
+        cache_db.expire(self.get_cache_key('otp_cache'), OTP_CACHE_TTL)
+        cache_db.set(self.get_cache_key('otp_cache'),
+            ','.join((code, remote_ip)))
         return True
 
     def _get_key_info_str(self, user_name, org_name, server_name):
@@ -365,14 +393,78 @@ class User(Config):
             'conf': client_conf,
         }
 
-    def clear_cache(self):
-        if self.type == CERT_CLIENT:
-            cache_db.decrement(self.org.get_cache_key('user_count'))
+    def send_key_email(self, key_link_domain):
+        email_from = persist_db.dict_get('auth', 'email_from')
+        email_api_key = persist_db.dict_get('auth', 'email_api_key')
+
+        if not email_from or not email_api_key:
+            raise EmailNotConfiguredError('Email not configured', {
+                'org_id': self.org.id,
+                'user_id': self.id,
+            })
+
+        key_link = self.org.create_user_key_link(self.id)
+        response = utils.request.post(POSTMARK_SERVER,
+            headers={
+                'Accept': 'application/json',
+                'Content-Type': 'application/json',
+                'X-Postmark-Server-Token': email_api_key,
+            },
+            json_data={
+                'From': email_from,
+                'To': self.email,
+                'Subject': 'Pritunl VPN Key',
+                'TextBody':  'Your vpn key and configuration can be ' +
+                    'downloaded from the temporary link below:\n\n' +
+                    key_link_domain + key_link['view_url'],
+            },
+        )
+        response = response.json()
+        error_code = response.get('ErrorCode')
+        error_msg = response.get('Message')
+
+        if error_code == 0:
+            pass
+        elif error_code == 10:
+            raise EmailApiKeyInvalid('Email api key invalid', {
+                'org_id': self.org.id,
+                'user_id': self.id,
+                'error_code': error_code,
+                'error_msg': error_msg,
+            })
+        elif error_code == 400:
+            raise EmailFromInvalid('Email from invalid', {
+                'org_id': self.org.id,
+                'user_id': self.id,
+                'error_code': error_code,
+                'error_msg': error_msg,
+            })
+        else:
+            logger.error('Unknown send user email error. %r' % {
+                'org_id': self.org.id,
+                'user_id': self.id,
+                'error_code': error_code,
+                'error_msg': error_msg,
+            })
+            raise EmailError('Unknown send user email error.', {
+                'org_id': self.org.id,
+                'user_id': self.id,
+                'error_code': error_code,
+                'error_msg': error_msg,
+            })
+
+    def clear_cache(self, org_data=True):
+        if org_data:
+            if self.type == CERT_CLIENT:
+                cache_db.decrement(self.org.get_cache_key('user_count'))
+            if self.type != CERT_CA:
+                cache_db.set_remove(self.org.get_cache_key('users'), self.id)
+                cache_db.list_remove(self.org.get_cache_key('users_sorted'),
+                    self.id)
         if self.type != CERT_CA:
-            cache_db.set_remove(self.org.get_cache_key('users'), self.id)
-            cache_db.list_remove(self.org.get_cache_key('users_sorted'),
-                self.id)
             self._remove_cache_trie_key()
+        cache_db.remove(self.get_cache_key('otp'))
+        cache_db.remove(self.get_cache_key('otp_cache'))
         Config.clear_cache(self)
 
     def rename(self, name):
