@@ -33,6 +33,7 @@ def get_remote_addr():
 
 def check_session():
     from pritunl import app_server
+    auth_valid = True
     auth_token = flask.request.headers.get('Auth-Token', None)
     if auth_token:
         auth_timestamp = flask.request.headers.get('Auth-Timestamp', None)
@@ -41,6 +42,7 @@ def check_session():
         if not auth_token or not auth_timestamp or not auth_nonce or \
                 not auth_signature:
             return False
+        auth_nonce = auth_nonce[:32]
 
         try:
             if abs(int(auth_timestamp) - int(time.time())) > AUTH_TIME_WINDOW:
@@ -51,15 +53,13 @@ def check_session():
         cache_key = 'auth_nonce-%s' % auth_nonce
         if cache_db.exists(cache_key):
             return False
-        cache_db.expire(cache_key, int(AUTH_TIME_WINDOW * 2.1))
-        cache_db.set(cache_key, auth_timestamp)
 
         auth_token_hash = persist_db.dict_get('auth', 'token')
         auth_secret = persist_db.dict_get('auth', 'secret')
         if not auth_token_hash or not auth_secret:
             return False
         if not _test_password_hash(auth_token_hash, auth_token):
-            return False
+            auth_valid = False
 
         auth_string = '&'.join([
             auth_token, auth_timestamp, auth_nonce, flask.request.method,
@@ -72,7 +72,11 @@ def check_session():
         auth_test_signature = base64.b64encode(hmac.new(
             auth_secret.encode(), auth_string, hashlib.sha256).digest())
         if auth_signature != auth_test_signature:
-            return False
+            auth_valid = False
+
+        if auth_valid:
+            cache_db.expire(cache_key, int(AUTH_TIME_WINDOW * 2.1))
+            cache_db.set(cache_key, auth_timestamp)
     else:
         if not flask.session:
             return False
@@ -90,7 +94,7 @@ def check_session():
                 flask.session['timestamp'] > app_server.session_timeout:
             flask.session.clear()
             return False
-    return True
+    return auth_valid
 
 def rmtree(path):
     subprocess.check_call(['rm', '-rf', path])
@@ -360,7 +364,10 @@ def set_auth(username, password, token=None):
 
 def get_auth():
     return {
-        'username': persist_db.dict_get('auth', 'username'),
+        'username': persist_db.dict_get(
+            'auth', 'username') or DEFAULT_USERNAME,
         'token': persist_db.dict_get('auth', 'token_enc'),
         'secret': persist_db.dict_get('auth', 'secret'),
+        'email_from': persist_db.dict_get('auth', 'email_from'),
+        'email_api_key': persist_db.dict_get('auth', 'email_api_key'),
     }
