@@ -17,4 +17,4 @@ print '#                                                            #'
 print '##############################################################'
 
 pritunl.app_server.conf_path = './tools/development_pritunl.conf'
-pritunl.app_server.run_all()
+pritunl.app_server.run_server()
