@@ -15,6 +15,8 @@ TEST_PASSWORD = 'unittest'
 TEST_USER_NAME = 'unittest_user'
 TEST_ORG_NAME = 'unittest_org'
 TEST_SERVER_NAME = 'unittest_server'
+TEST_EMAIL_FROM = 'test_email_from'
+TEST_EMAIL_API_KEY = 'test_email_api_key'
 ENABLE_STANDARD_TESTS = True
 ENABLE_EXTENDED_TESTS = False
 ENABLE_STRESS_TESTS = False
@@ -269,10 +271,25 @@ class Auth(SessionTestCase):
         response = self.session.put('/auth', json_data={
             'username': USERNAME,
             'password': TEST_PASSWORD,
+            'email_from': TEST_EMAIL_FROM,
+            'email_api_key': TEST_EMAIL_API_KEY,
         })
         self.assertEqual(response.status_code, 200)
 
 
+        response = self.session.get('/auth')
+        self.assertEqual(response.status_code, 200)
+
+        data = response.json()
+        self.assertIn('username', data)
+        self.assertIn('token', data)
+        self.assertIn('secret', data)
+        self.assertIn('email_from', data)
+        self.assertEqual(data['email_from'], TEST_EMAIL_FROM)
+        self.assertIn('email_api_key', data)
+        self.assertEqual(data['email_api_key'], TEST_EMAIL_API_KEY)
+
+
         response = self.session.put('/auth', json_data={
             'username': USERNAME,
             'password': PASSWORD,
@@ -598,6 +615,7 @@ class Server(SessionTestCase):
             'mode': 'local_traffic',
             'local_networks': ['10.0.0.0/24'],
             'dns_servers': ['8.8.4.4'],
+            'search_domain': 'pritunl.com',
             'public_address': '8.8.8.8',
             'debug': True,
             'otp_auth': False,
@@ -626,6 +644,8 @@ class Server(SessionTestCase):
         self.assertEqual(data['local_networks'], ['10.0.0.0/24'])
         self.assertIn('dns_servers', data)
         self.assertEqual(data['dns_servers'], ['8.8.4.4'])
+        self.assertIn('search_domain', data)
+        self.assertEqual(data['search_domain'], 'pritunl.com')
         self.assertIn('public_address', data)
         self.assertEqual(data['public_address'], '8.8.8.8')
         self.assertIn('debug', data)
@@ -665,6 +685,8 @@ class Server(SessionTestCase):
         self.assertEqual(data['dns_servers'], ['8.8.4.4'])
         self.assertIn('public_address', data)
         self.assertEqual(data['public_address'], '8.8.8.8')
+        self.assertIn('search_domain', data)
+        self.assertEqual(data['search_domain'], 'pritunl.com')
         self.assertIn('debug', data)
         self.assertTrue(data['debug'])
         self.assertIn('otp_auth', data)
@@ -691,6 +713,7 @@ class Server(SessionTestCase):
             self.assertIn('mode', server)
             self.assertIn('local_networks', server)
             self.assertIn('dns_servers', server)
+            self.assertIn('search_domain', server)
             self.assertIn('public_address', server)
             self.assertIn('debug', server)
             self.assertIn('otp_auth', server)
@@ -707,6 +730,7 @@ class Server(SessionTestCase):
                 self.assertEqual(server['mode'], 'local_traffic')
                 self.assertEqual(server['local_networks'], ['10.0.0.0/24'])
                 self.assertEqual(server['dns_servers'], ['8.8.4.4'])
+                self.assertEqual(server['search_domain'], 'pritunl.com')
                 self.assertEqual(server['public_address'], '8.8.8.8')
                 self.assertTrue(server['debug'])
                 self.assertFalse(server['otp_auth'])
@@ -1074,10 +1098,13 @@ class User(SessionTestCase):
         self.assertEqual(data['id'], self.user_id)
         self.assertIn('name', data)
         self.assertEqual(data['name'], TEST_USER_NAME)
+        self.assertIn('disabled', data)
+        self.assertFalse(data['disabled'])
 
     def test_user_post_put_get_delete(self):
         response = self.session.post('/user/%s' % self.org_id, json_data={
             'name': TEST_USER_NAME + '2',
+            'disabled': True,
         })
         self.assertEqual(response.status_code, 200)
 
@@ -1090,6 +1117,8 @@ class User(SessionTestCase):
         self.assertEqual(data['organization_name'], TEST_ORG_NAME)
         self.assertIn('name', data)
         self.assertEqual(data['name'], TEST_USER_NAME + '2')
+        self.assertIn('disabled', data)
+        self.assertTrue(data['disabled'])
         self.assertIn('type', data)
         self.assertIn('otp_secret', data)
         user_id = data['id']
@@ -1110,6 +1139,29 @@ class User(SessionTestCase):
         self.assertEqual(data['organization_name'], TEST_ORG_NAME)
         self.assertIn('name', data)
         self.assertEqual(data['name'], TEST_USER_NAME + '3')
+        self.assertIn('disabled', data)
+        self.assertTrue(data['disabled'])
+        self.assertIn('type', data)
+        self.assertIn('otp_secret', data)
+
+
+        response = self.session.put('/user/%s/%s' % (self.org_id, user_id),
+            json_data={
+                'disabled': False,
+            })
+        self.assertEqual(response.status_code, 200)
+
+        data = response.json()
+        self.assertIn('id', data)
+        self.assertRegexpMatches(data['id'], UUID_RE)
+        self.assertIn('organization', data)
+        self.assertEqual(data['organization'], self.org_id)
+        self.assertIn('organization_name', data)
+        self.assertEqual(data['organization_name'], TEST_ORG_NAME)
+        self.assertIn('name', data)
+        self.assertEqual(data['name'], TEST_USER_NAME + '3')
+        self.assertIn('disabled', data)
+        self.assertFalse(data['disabled'])
         self.assertIn('type', data)
         self.assertIn('otp_secret', data)
 
@@ -1126,6 +1178,7 @@ class User(SessionTestCase):
             self.assertIn('organization', user)
             self.assertIn('organization_name', user)
             self.assertIn('name', user)
+            self.assertIn('disabled', user)
             self.assertIn('type', user)
             self.assertIn('status', user)
             self.assertIn('otp_auth', user)
@@ -1134,6 +1187,7 @@ class User(SessionTestCase):
 
             if user['name'] == TEST_USER_NAME + '3':
                 test_user_found = True
+                self.assertFalse(user['disabled'])
                 self.assertEqual(user['organization'], self.org_id)
                 self.assertEqual(user['organization_name'], TEST_ORG_NAME)
         self.assertTrue(test_user_found)
@@ -1168,6 +1222,8 @@ class User(SessionTestCase):
         self.assertEqual(data['organization_name'], TEST_ORG_NAME)
         self.assertIn('name', data)
         self.assertEqual(data['name'], TEST_USER_NAME)
+        self.assertIn('disabled', data)
+        self.assertFalse(data['disabled'])
         self.assertIn('type', data)
         self.assertIn('otp_secret', data)
         self.assertNotEqual(data['otp_secret'], orig_otp_secret)
