@@ -33,7 +33,9 @@ define([
     request.response({
       username: demoData.auth.username,
       token: demoData.auth.token,
-      secret: demoData.auth.secret
+      secret: demoData.auth.secret,
+      email_from: demoData.auth.email_from,
+      email_api_key: demoData.auth.email_api_key
     });
   };
   routes['GET=/auth'] = authGet;
@@ -41,6 +43,8 @@ define([
   var authPut = function(request) {
     demoData.auth.username = request.data.username;
     demoData.auth.password = request.data.password;
+    demoData.auth.email_from = request.data.email_from;
+    demoData.auth.email_api_key = request.data.email_api_key;
     if (!request.data.token) {
       demoData.auth.token = uuid();
       demoData.auth.secret = uuid();
@@ -274,8 +278,6 @@ define([
 
       serverStatus = demoData.servers[serverId].status;
       servers.push(_.extend({
-        status: serverStatus,
-        uptime: serverStatus ? 109800 : null,
         users_online: serverStatus && userCount ? 1 : 0,
         user_count: userCount,
         org_count: demoData.servers[serverId].orgs.length
@@ -300,6 +302,7 @@ define([
       mode: request.data.mode,
       local_networks: request.data.local_networks,
       dns_servers: request.data.dns_servers,
+      search_domain: request.data.search_domain,
       public_address: request.data.public_address,
       otp_auth: request.data.otp_auth,
       lzo_compression: request.data.lzo_compression,
@@ -327,6 +330,7 @@ define([
     demoData.servers[serverId].mode = request.data.mode;
     demoData.servers[serverId].local_networks = request.data.local_networks;
     demoData.servers[serverId].dns_servers = request.data.dns_servers;
+    demoData.servers[serverId].search_domain = request.data.search_domain;
     demoData.servers[serverId].public_address = request.data.public_address;
     demoData.servers[serverId].otp_auth = request.data.otp_auth;
     demoData.servers[serverId].lzo_compression = request.data.lzo_compression;
@@ -386,16 +390,19 @@ define([
   var serverOperationPut = function(request, serverId, operation) {
     if (operation === 'start') {
       demoData.servers[serverId].status = true;
+      demoData.servers[serverId].uptime = 1;
       demoData.servers[serverId].output = demoData.serverOutput.online;
       logEntry('Started server "' + demoData.servers[serverId].name + '".');
     }
     else if (operation === 'stop') {
       demoData.servers[serverId].status = false;
+      demoData.servers[serverId].uptime = null;
       demoData.servers[serverId].output += demoData.serverOutput.offline;
       logEntry('Stopped server "' + demoData.servers[serverId].name + '".');
     }
     else {
       demoData.servers[serverId].status = true;
+      demoData.servers[serverId].uptime = 1;
       demoData.servers[serverId].output += demoData.serverOutput.offline;
       demoData.servers[serverId].output += demoData.serverOutput.online;
       logEntry('Restarted server "' + demoData.servers[serverId].name + '".');
@@ -522,6 +529,7 @@ define([
       id: userId,
       organization: orgId,
       name: request.data.name,
+      email: request.data.email,
       type: 'client',
       status: false,
       otp_auth: true,
@@ -547,7 +555,15 @@ define([
   routes['POST=/user/<orgId>'] = userPost;
 
   var userPut = function(request, orgId, userId) {
-    demoData.users[orgId][userId].name = request.data.name;
+    if (request.data.name) {
+      demoData.users[orgId][userId].name = request.data.name;
+    }
+    if (request.data.email !== undefined) {
+      demoData.users[orgId][userId].email = request.data.email;
+    }
+    if (request.data.disabled !== undefined) {
+      demoData.users[orgId][userId].disabled = request.data.disabled;
+    }
     event('users_updated', orgId);
     request.response({});
   };
@@ -573,7 +589,8 @@ define([
     request.response({
       id: uuid(),
       key_url: '/key/demo.tar',
-      view_url: '/key/demo.html'
+      view_url: '/key/demo.html',
+      uri_url: '/k/demo'
     });
   };
   routes['GET=/key/<org_id>/<user_id>'] = keyGet;
