@@ -6,10 +6,10 @@ define([
   'models/authSession',
   'views/alert',
   'views/loginBackdrop',
-  'views/modalChangePassword',
+  'views/modalSettings',
   'text!templates/login.html'
 ], function($, _, Backbone, AuthModel, AuthSessionModel, AlertView,
-    LoginBackdropView, ModalChangePasswordView, loginTemplate) {
+    LoginBackdropView, ModalSettingsView, loginTemplate) {
   'use strict';
   var LoginView = Backbone.View.extend({
     className: 'login',
@@ -28,7 +28,7 @@ define([
       this.active = true;
       this.alert = options.alert;
       this.callback = options.callback;
-      this.showChangePassword = options.showChangePassword;
+      this.showSettings = options.showSettings;
       this.backdrop = new LoginBackdropView();
       this.addView(this.backdrop);
     },
@@ -79,14 +79,14 @@ define([
       this.addView(this.alertView);
       this.$('input').addClass('has-warning');
     },
-    changePassword: function(username, password, initial) {
+    openSettings: function(username, password, initial) {
       var model = new AuthModel({
         username: username,
         password: password
       });
       model.fetch({
         success: function() {
-          var modal = new ModalChangePasswordView({
+          var modal = new ModalSettingsView({
             initial: initial,
             model: model
           });
@@ -135,11 +135,11 @@ define([
             complete: function() {
               var initial;
               this.destroy();
-              if (model.get('default_password') || this.showChangePassword) {
-                if (!this.showChangePassword) {
+              if (model.get('default_password') || this.showSettings) {
+                if (!this.showSettings) {
                   initial = true;
                 }
-                this.changePassword(username, password, initial);
+                this.openSettings(username, password, initial);
               }
               window.loginViewLock = false;
             }.bind(this)
