@@ -22,15 +22,29 @@ define([
       });
     },
     onOk: function() {
-      if (!this.$('input').val()) {
-        this.setAlert('danger', 'Name can not be empty.', '.form-group');
+      var name = this.$('.name input').val();
+      var org = this.$('.org select').val();
+      var email = this.$('.email input').val();
+      var emailReg = /^\w+([-+.']\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*$/;
+
+      if (!name) {
+        this.setAlert('danger', 'Name can not be empty.', '.form-group.name');
         return;
       }
+      if (!email) {
+        email = null;
+      }
+      else if (!emailReg.test(email)) {
+        this.setAlert('danger', 'Email is not valid.', '.form-group.email');
+        return;
+      }
+
       this.setLoading('Adding user...');
       var userModel = new UserModel();
       userModel.save({
-        organization: this.$('select').val(),
-        name: this.$('input').val()
+        organization: org,
+        name: name,
+        email: email
       }, {
         success: function() {
           this.close(true);
