@@ -9,19 +9,32 @@ define([
   var ModalRenameUserView = ModalView.extend({
     className: 'rename-user-modal',
     template: _.template(modalRenameUserTemplate),
-    title: 'Rename User',
-    okText: 'Rename',
+    title: 'Modify User',
+    okText: 'Save',
     body: function() {
       return this.template(this.model.toJSON());
     },
     onOk: function() {
-      if (!this.$('input').val()) {
-        this.setAlert('danger', 'Name can not be empty.', '.form-group');
+      var name = this.$('.name input').val();
+      var email = this.$('.email input').val();
+      var emailReg = /^\w+([-+.']\w+)*@\w+([-.]\w+)*\.\w+([-.]\w+)*$/;
+
+      if (!name) {
+        this.setAlert('danger', 'Name can not be empty.', '.form-group.name');
         return;
       }
-      this.setLoading('Renaming user...');
+      if (!email) {
+        email = null;
+      }
+      else if (!emailReg.test(email)) {
+        this.setAlert('danger', 'Email is not valid.', '.form-group.email');
+        return;
+      }
+
+      this.setLoading('Modifying user...');
       this.model.save({
-        name: this.$('input').val()
+        name: name,
+        email: email
       }, {
         success: function() {
           this.close(true);
@@ -29,7 +42,7 @@ define([
         error: function() {
           this.clearLoading();
           this.setAlert('danger',
-            'Failed to rename user, server error occurred.');
+            'Failed to modify user, server error occurred.');
         }.bind(this)
       });
     }
