@@ -30,7 +30,7 @@ define([
       return this.template(this.model.toJSON());
     },
     postRender: function() {
-      if (this.model.get('local_networks').length) {
+      if (this.model.get('mode') === 'local_traffic') {
         this.$('.otp-auth-toggle').appendTo('.left');
       }
       this.$('.local-network input').select2({
@@ -160,8 +160,8 @@ define([
       var name = this.$('.name input').val();
       var network = this.$('.network input').val();
       var iface = this.$('.interface input').val();
-      var port = this.$('.port input').val();
-      var protocol = this.$('.protocol select').val();
+      var port = this.$('input.port').val();
+      var protocol = this.$('select.protocol').val();
       var dhParamBits = parseInt(this.$('.dh-param-bits select').val(), 10);
       var mode = this.$('.server-mode select').val();
       var publicAddress = this.$('.public-address input').val();
@@ -173,6 +173,7 @@ define([
           dnsServers.push(dnsServersTemp[i]);
         }
       }
+      var searchDomain = this.$('.search-domain input').val();
       var nodeHost = this.$('.node-host input').val().split(':');
       var nodePort = null;
       if (nodeHost.length > 1) {
@@ -197,7 +198,7 @@ define([
         return;
       }
       if (!port) {
-        this.setAlert('danger', 'Port can not be empty.', '.port');
+        this.setAlert('danger', 'Port can not be empty.', 'input.port');
         return;
       }
       if (!publicAddress) {
@@ -213,6 +214,9 @@ define([
           return;
         }
       }
+      if (!searchDomain) {
+        searchDomain = null;
+      }
 
       var data = {
         'name': name,
@@ -225,6 +229,7 @@ define([
         'mode': mode,
         'local_networks': localNetworks,
         'dns_servers': dnsServers,
+        'search_domain': searchDomain,
         'public_address': publicAddress,
         'otp_auth': otpAuth,
         'debug': debug
