@@ -12,10 +12,14 @@ define([
       this.model = new ServerOutputModel({
         id: options.server
       });
+      this.state = true;
       this.listenTo(window.events, 'server_output_updated:' + options.server,
         this.update);
     },
     update: function() {
+      if (!this.getState()) {
+        return;
+      }
       this.model.fetch({
         error: function() {
           var alertView = new AlertView({
@@ -31,6 +35,22 @@ define([
           this.setData(this.model.get('output'));
         }.bind(this)
       });
+    },
+    setState: function(state) {
+      if (this.getState() === state) {
+        return;
+      }
+      this.state = state;
+      if (state) {
+        this.$el.parent().show();
+        this.update();
+      }
+      else {
+        this.$el.parent().hide();
+      }
+    },
+    getState: function() {
+      return this.state;
     }
   });
 
